@@ -241,7 +241,7 @@ void m_batch_convert(GtkWidget *, ch *)
       statmess[im] = "waiting";                                                  //  conversion status
    }
    
-   zdpop = popup_report_open("converting files",Mwin,600,300,0,0,0,"X",0);       //  open popup report
+   zdpop = popup_report_open("converting files",Mwin,600,300,0,0,0,"X",null);    //  open popup report
    zmainloop();
 
    for (im = 0; im < NT; im++)                                                   //  start threads for conversion work
@@ -874,7 +874,7 @@ void m_batch_copy_move(GtkWidget *, ch *)
    cc = strlen(newloc);                                                          //  output location
    if (newloc[cc-1] == '/') newloc[cc-1] = 0;                                    //  remove trailing '/'
 
-   zdpop = popup_report_open("Processing files",Mwin,600,300,0,0,0,"X",0);       //  log report
+   zdpop = popup_report_open("Processing files",Mwin,600,300,0,0,0,"X",null);    //  log report
 
    Funcbusy(+1);                                                                 //  24.10
 
@@ -1132,7 +1132,7 @@ void m_batch_upright(GtkWidget *, ch *)
       if (! yn) goto cleanup;
    }
 
-   zdpop = popup_report_open("Processing files",Mwin,500,200,0,0,0,"X",0);       //  log report
+   zdpop = popup_report_open("Processing files",Mwin,500,200,0,0,0,"X",null);    //  log report
 
    Funcbusy(+1);                                                                 //  24.10
    
@@ -1337,7 +1337,7 @@ void m_batch_deltrash(GtkWidget *, ch *)
 
    free_resources();                                                             //  no curr. file
 
-   zdpop = popup_report_open("Processing files",Mwin,500,200,0,0,0,"X",0);       //  log report
+   zdpop = popup_report_open("Processing files",Mwin,500,200,0,0,0,"X",null);    //  log report
 
    Funcbusy(+1);                                                                 //  24.10
 
@@ -1362,7 +1362,7 @@ void m_batch_deltrash(GtkWidget *, ch *)
          err = f_remove(file,"trash");
       if (err) {
          popup_report_write2(zdpop,1,"move to trash failed \n");                 //  gnome trash failed
-         nn = zdialog_choose(Mwin,"parent","continue?","Yes","Quit",0);
+         nn = zdialog_choose(Mwin,"parent","continue?","Yes","Quit",null);
          if (nn == 2) {                                                          //  quit
             zdpop->zstat = 1;
             break;
@@ -1594,7 +1594,7 @@ void m_batch_overlay(GtkWidget *, ch *)
 
    free_resources();                                                             //  no current file                       24.30
 
-   zdpop = popup_report_open("Processing files",Mwin,600,300,0,0,0,"X",0);       //  log report
+   zdpop = popup_report_open("Processing files",Mwin,600,300,0,0,0,"X",null);    //  log report
 
    Funcbusy(+1);                                                                 //  24.10
 
@@ -2055,7 +2055,7 @@ void m_export_files(GtkWidget*, ch *menu)
 
    free_resources();                                                             //  no current file                       24.30
 
-   zdpop = popup_report_open("exporting files",Mwin,600,400,0,0,0,"X",0);        //  log report
+   zdpop = popup_report_open("exporting files",Mwin,600,400,0,0,0,"X",null);     //  log report
 
    Funcbusy(+1);                                                                 //  24.10
 
